Triple

Struct Triple 

pub struct Triple {
    pub architecture: Architecture,
    pub vendor: Vendor,
    pub operating_system: OperatingSystem,
    pub environment: Environment,
    pub binary_format: BinaryFormat,
}
An LLVM target “triple”. Historically such things had three fields, though they’ve added additional fields over time.

Note that Triple doesn’t implement Default itself. If you want a type which defaults to the host triple, or defaults to unknown-unknown-unknown, use DefaultToHost or DefaultToUnknown, respectively.

Fields

architecture: Architecture

The “architecture” (and sometimes the subarchitecture).

vendor: Vendor

The “vendor” (whatever that means).

operating_system: OperatingSystem

The “operating system” (sometimes also the environment).

environment: Environment

The “environment” on top of the operating system (often omitted for operating systems with a single predominant environment).

binary_format: BinaryFormat

The “binary format” (rarely used).

Implementations

Source

impl Triple

pub const fn host() -> Triple

Return the triple for the current host.

Source

impl Triple

pub fn endianness(&self) -> Result<Endianness, ()>

Return the endianness of this target’s architecture.

pub fn pointer_width(&self) -> Result<PointerWidth, ()>

Return the pointer width of this target’s architecture.

This function is aware of x32 and ilp32 ABIs on 64-bit architectures.

pub fn default_calling_convention(&self) -> Result<CallingConvention, ()>

Return the default calling convention for the given target triple.

pub fn data_model(&self) -> Result<CDataModel, ()>

The C data model for a given target. If the model is not known, returns Err(()).

pub fn unknown() -> Triple

Return a Triple with all unknown fields.